@@ -1,5 +1,5 @@
 
-# $Id: Ebay.pm,v 2.247 2009-08-11 01:37:29 Martin Exp $
+# $Id: Ebay.pm,v 2.248 2009-08-11 01:45:17 Martin Exp $
 
 =head1 NAME
 
@@ -156,7 +156,7 @@ use WWW::SearchResult 2.072;
 use WWW::Search::Result;
 
 our
-$VERSION = do { my @r = (q$Revision: 2.247 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.248 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 our $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 my $cgi = new CGI;
 
@@ -411,7 +411,7 @@ sub _parse_price
   my $currency = $self->_currency_pattern;
   my $W = $self->whitespace_pattern;
   $iPrice =~ s!($currency)$W*($currency)!$1 (Buy-It-Now for $2)!;
-  if ($iPrice =~ s/Free\s+Shipping//)
+  if ($iPrice =~ s/Free\s+Shipping//i)
     {
     $hit->shipping('free');
     } # if
